@@ -2,7 +2,7 @@
 
 __author__ = 'Gareth Price'
 __email__ = 'gareth.price@warwick.ac.uk'
-__version__ = '2.2.2'
+__version__ = '2.3.0'
 
 import sys
 import os
@@ -15,52 +15,59 @@ def log(message="", verbose=True, colour=None, background=None, bold=False, unde
         string. If run=True, the following print command (or log())
         will appear on the same line.
     """
-
-    if verbose:
-
-        colours = {
-            'black':    '90',
-            'red':      '91',
-            'green':    '92',
-            'yellow':   '93',
-            'blue':     '94',
-            'magenta':  '95',
-            'cyan':     '96',
-            'white':    '97',
-        }
-
-        backgrounds = {
-            'default':  '49',
-            'black':    '100',
-            'red':      '101',
-            'green':    '102',
-            'yellow':   '103',
-            'blue':     '104',
-            'magenta':  '105',
-            'cyan':     '106',
-            'white':    '107'
-        }
-
-        if bold:
-            message = '\033[1m' + message + '\033[21m'
-        if underline:
-            message = '\033[4m' + message + '\033[24m'
-        if background is not None:
-            message = '\033[' + backgrounds[background] + \
-                'm' + message + '\033[49m'
-        if colour is not None:
-            message = '\033[' + colours[colour] + 'm' + message + '\033[0m'
-        if inverted:
-            message = '\033[7m' + message + '\033[27m'
-
+    if 'linux' in sys.platform:
         if ret:
             return message
-
         if run:
             print message,
         else:
             print message
 
+    elif 'darwin' in sys.platform:
+        if verbose:
+
+            colours = {
+                'black':    '90',
+                'red':      '91',
+                'green':    '92',
+                'yellow':   '93',
+                'blue':     '94',
+                'magenta':  '95',
+                'cyan':     '96',
+                'white':    '97',
+            }
+
+            backgrounds = {
+                'default':  '49',
+                'black':    '100',
+                'red':      '101',
+                'green':    '102',
+                'yellow':   '103',
+                'blue':     '104',
+                'magenta':  '105',
+                'cyan':     '106',
+                'white':    '107'
+            }
+
+            if bold:
+                message = '\033[1m' + message + '\033[21m'
+            if underline:
+                message = '\033[4m' + message + '\033[24m'
+            if background is not None:
+                message = '\033[' + backgrounds[background] + \
+                    'm' + message + '\033[49m'
+            if colour is not None:
+                message = '\033[' + colours[colour] + 'm' + message + '\033[0m'
+            if inverted:
+                message = '\033[7m' + message + '\033[27m'
+
+            if ret:
+                return message
+            if run:
+                print message,
+            else:
+                print message
+
     return
 
 
@@ -71,14 +78,20 @@ def logHeader(message):
     print message
 
 def printHeader(message):
-    print """\r   \033[38;5;204m{message:<20}\033[0m """.format(message=message)
+    if 'linux' in sys.platform:
+        print """\r   {message:<20} """.format(message=message)
+    if 'darwin' in sys.platform:
+        print """\r   \033[38;5;204m{message:<20}\033[0m """.format(message=message)
 
 
 class ProgressBar(object):
     """A Simple class for showing a progress bar to the user"""
 
     def __init__(self, progress, total, message, newline=True):
-        message = """  \033[38;5;204m{message:<20}\033[0m """.format(message=message)
+        if 'linux' in sys.platform:
+            message = "{message:<20}".format(message=message)
+        elif 'linux' in sys.platform:
+            message = """  \033[38;5;204m{message:<20}\033[0m """.format(message=message)
 
         import time
         time.sleep(0.01)
